@@ -5,7 +5,7 @@ Pherkin::Extension::Weasel - Pherkin extension for web-testing
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 0.18
 
 =cut
 
-package Pherkin::Extension::Weasel 0.18;
+package Pherkin::Extension::Weasel 0.19;
 
 use strict;
 use warnings;
@@ -428,7 +428,7 @@ has dom_save_events => (is => 'ro',
                         },
     );
 
-=has logging_dir
+=item logging_dir
 
 Name of directory to store the browser-interaction logs
 
